@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 import pytest
 
-from pendulum.tz import timezone
+from pendulum import timezone
+from pendulum.tz.exceptions import InvalidTimezone
 from pendulum.tz.timezone import FixedTimezone
 from pendulum.tz.timezone import Timezone
-from pendulum.tz.zoneinfo.exceptions import InvalidTimezone
 
 
 def test_timezone_with_name():
